/*
 * Copyright 2005, 2006 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.core;

import com.torunski.crawler.events.IParserEventListener;
import com.torunski.crawler.filter.ILinkFilter;
import com.torunski.crawler.model.ICrawlerModel;
import com.torunski.crawler.parser.IParser;

/**
 * All crawlers implement the common methods descriped below.
 *  
 * @author Lars Torunski
 * @version $Revision: 1.3 $
 */
public interface ICrawler {

	/**
	 * @return Returns the parser.
	 */
	public IParser getParser();

	/**
	 * @param parser The parser to set.
	 */
	public void setParser(IParser parser);

	/**
	 * @return Returns the crawler model.
	 */
	public ICrawlerModel getModel();

	/**
	 * @param model The crawler model to set.
	 */
	public void setModel(ICrawlerModel model);

	/**
	 * @return Returns the linkFilter.
	 */
	public ILinkFilter getLinkFilter();

	/**
	 * @param linkFilter The linkFilter to set.
	 */
	public void setLinkFilter(ILinkFilter linkFilter);

	/**
	 * @param l listener to be added to the event list.
	 */
	public void addParserListener(IParserEventListener l);

	/**
	 * @param l listener to be removed from the event list.
	 */
	public void removeParserListener(IParserEventListener l);

	/**
	 * Starts the crawling process.
	 */
	public void start();

}