/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.events;

import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import com.torunski.crawler.link.LinkGraph;

/**
 * Creates a link graph of the links.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.3 $
 */
public class LinkGraphParserEventListener implements IParserEventListener {

    /** the origin of the link graph */
    private LinkGraph origin = null;

    /**
     * @return Returns the origin of the link graph.
     */
    public LinkGraph getOrigin() {
        return origin;
    }
    
    /** find links fast */
    private HashMap links = new HashMap();
    
    /**
     * @return the collection of graph links of this link graph
     */
    public Collection getLinks() {
        return links.values();
    }    
    
    /**
     * @param uri the URI of the link to be returned
     * @param create if link doesn't exists, the link will be created, else null will be returned
     * @return a link graph of the URI
     */
    public LinkGraph getLink(String uri, boolean create) {
        // find the link
        LinkGraph link = (LinkGraph) links.get(uri);
        
        if (link == null) {
            link = new LinkGraph(uri);
            links.put(uri, link);
            
            // set the origin
            if (origin == null) {
                origin = link;
            }
        }
        
        return link;
    }
    
    /**
     * @param uri the URI of the link to be returned
     * @return a link graph of the URI or null if link doesn't exists in the graph
     */
    public LinkGraph getLink(String uri) {
        return getLink(uri, false);
    }

    /**
     * @see com.torunski.crawler.events.IParserEventListener#parse(com.torunski.crawler.events.ParserEvent)
     */
    public void parse(ParserEvent event) {
        // get the origin link
        LinkGraph originLink = getLink(event.getLink().getURI(), true);
        
        // set the outgoing links
        Iterator iterator = event.getOutLinks().iterator();
        while (iterator.hasNext()) {
            originLink.addToOutLinks(getLink((String) iterator.next()));
        }
    }
    
}
