/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.filter;

/**
 * The beginning path link filter. The filter accepts links
 * which begins with the same characters of links in the accept list.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.2 $
 */
public class BeginningPathFilter implements ILinkFilter {
    
    /** the accept list of links */
    private String[] acceptList;

    /**
     * Constructor for BeginningPathFilter.
     * @param path
     */
    public BeginningPathFilter(String path) {
        acceptList = new String[] {path.toLowerCase()};
    }

    /**
     * Constructor for BeginningPathFilter.
     * @param acceptList a list of links
     */
    public BeginningPathFilter(String[] acceptList) {
        this.acceptList = new String[acceptList.length];
        for (int i = 0; i < acceptList.length; i++) {
            this.acceptList[i] = acceptList[i].toLowerCase();
        }
    }

    /** 
     * @see com.torunski.crawler.filter.ILinkFilter#accept(java.lang.String, java.lang.String)
     */
    public boolean accept(String origin, String link) {
        if (link == null) {
            return false;
        }
        
        String checkLink = link.toLowerCase();
        
        // remove server from link
        if (!checkLink.startsWith("http://") && checkLink.startsWith("http:/")) {
            checkLink = checkLink.substring(5);
        } else if (checkLink.startsWith("http://")) {
            checkLink = checkLink.substring(7);
            int i = checkLink.indexOf('/', 0);
            if (i < 0) {
                checkLink = "/";
            } else {
                checkLink = checkLink.substring(i);
            }
        }

        
        for (int i = 0; i < acceptList.length; i++) {
            if (checkLink.startsWith(acceptList[i])) {
                return true;
            }
        }
        
        return false;
    }

}
