/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.filter;

/**
 * Link filter utilities for AND, OR and NOT.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.3 $
 */
public class LinkFilterUtil  {
    
    // --- AND LinkFilter ---
    
    public static final ILinkFilter and(ILinkFilter filter1, ILinkFilter filter2) {
        return new And(filter1, filter2);
    }
    
    private static final class And implements ILinkFilter {
        
        private ILinkFilter f1;
        private ILinkFilter f2;
        
        public And(ILinkFilter f1, ILinkFilter f2) {
            this.f1 = f1;
            this.f2 = f2;
        }

        public boolean accept(String origin, String link) {
            return f1.accept(origin, link) && f2.accept(origin, link);
        }
        
    }
    
    // --- OR LinkFilter ---
    
    public static final ILinkFilter or(ILinkFilter filter1, ILinkFilter filter2) {
        return new Or(filter1, filter2);
    }
    
    private static final class Or implements ILinkFilter {
        
        private ILinkFilter f1;
        private ILinkFilter f2;
        
        public Or(ILinkFilter f1, ILinkFilter f2) {
            this.f1 = f1;
            this.f2 = f2;
        }

        public boolean accept(String origin, String link) {
            return f1.accept(origin, link) || f2.accept(origin, link);
        }
        
    }
    
    // --- NOT LinkFilter ---
    
    public static final ILinkFilter not(ILinkFilter filter) {
        return new Not(filter);
    }
    
    private static final class Not implements ILinkFilter {
        
        private ILinkFilter filter;
        
        public Not(ILinkFilter filter) {
            this.filter = filter;
        }

        public boolean accept(String origin, String link) {
            return !filter.accept(origin, link);
        }
        
    }
    
    // --- XOR LinkFilter ---
    
    // TODO unit test for this
    
    public static final ILinkFilter xor(ILinkFilter filter1, ILinkFilter filter2) {
        return new Xor(filter1, filter2);
    }
    
    private static final class Xor implements ILinkFilter {
        
        private ILinkFilter f1;
        private ILinkFilter f2;
        
        public Xor(ILinkFilter f1, ILinkFilter f2) {
            this.f1 = f1;
            this.f2 = f2;
        }

        public boolean accept(String origin, String link) {
        	boolean acceptF1 = f1.accept(origin, link); 
        	boolean acceptF2 = f2.accept(origin, link);
            return ((acceptF1 && !acceptF2) || (!acceptF1 && acceptF2));
        }
        
    }
    
}
