/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.filter;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * A ILinkFilter that filters URIs based on a regular expression.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.1 $
 */
public class RegularExpressionFilter implements ILinkFilter {
    
    /** The pattern of the filter */
    private Pattern pattern;
    
    /**
     * Constructor for RegExprFilter.
     * 
     * @param regex the regular expression of the filter.
     */
    public RegularExpressionFilter(String regex) {
        pattern = Pattern.compile(regex);
    }

    /**
     * Filters links which matches the pattern.
     * 
     * @see com.torunski.crawler.filter.ILinkFilter#accept(java.lang.String, java.lang.String)
     */
    public boolean accept(String origin, String link) {
        Matcher m = pattern.matcher(link);
        return m.matches();
    }

}
