/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.filter;

/**
 * A ILinkFilter that filters URIs for a special server only.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.4 $
 */
public class ServerFilter implements ILinkFilter {
    
    /** The specified server to filter for */
    private String server;
    
    /**
     * Constructor for ServerFilter.
     * 
     * @param server the server to filter for.
     */
    public ServerFilter(String server) {
        this.server = server;
    }

    /**
     * Filters links which was specified in the constructor, only these would be filtered.
     * 
     * @see com.torunski.crawler.filter.ILinkFilter#accept(java.lang.String, java.lang.String)
     */
    public boolean accept(String origin, String link) {
        return (link != null) && (link.startsWith(server)); 
    }

}
