/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.model;

import java.util.Collection;
import java.util.NoSuchElementException;

import com.torunski.crawler.link.Link;

/**
 * Defines the methods for the crawler model.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.5 $
 */
public interface ICrawlerModel {
    
    /**
     * Returns <tt>true</tt> if the crawler model has no more links. (In other
     * words, returns <tt>false</tt> if <tt>pop</tt> would return an element
     * rather than throwing an exception.)
     *
     * @return <tt>true</tt> if the crawler model has no more links.
     */
    public boolean isEmpty();
    
    /**
     * Returns the next link in the crawler model. The method removes
     * the link from the to visit list and adds the link to the visited list.
     *
     * @return the next link in the crawler model.
     * @exception NoSuchElementException crawler model has no more elements.
     */
    public Link pop();
    
    /**
     * Adds a <b>new</b> URI to the to be visted URIs.
     * @param origin the origin link of the new URI
     * @param uri adds a new link with the URI to the crawler model.
     */
    public void add(Link origin, String uri);
    
    /**
     * Adds <b>new</b> URIs to the to be visited URIs.
     * @param origin the origin link of the new URI
     * @param uri adds new links with the URIs (in the collection) to the crawler model.
     */
    public void add(Link origin, Collection uri);
    
    /**
     * Creates a <b>new</b> link based on the orginUri and uri parameter.
     * @param originUri the origin URI of the link
     * @param uri the new URI
     */
    public Link createLink(String originUri, String uri);

    /**
     * @return a object set of visited URIs.
     */
    public Collection getVisitedURIs();
    
    /**
     * @return a object set of still to be visited URIs.
     */
    public Collection getToVisitURIs();
    
    
    
}
