/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.parser;

import com.torunski.crawler.link.Link;

/**
 * Defines an abstract container for the downloaded page.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.3 $
 */
abstract public class PageData {

    public static final int NOT_LOADED = 0;
    public static final int OK = 1;
    public static final int ERROR = 2;
    
    /** The link of this data */
    private Link link;
    
    /** The status of the data */
    private int status;

    /**
     * The default constructor.
     * 
     * @param link the link of the page data.
     */
    public PageData(Link link) {
        this(link, NOT_LOADED);
    }
    
    /**
     * The default constructor.
     * 
     * @param link the link of the page data.
     * @param status the status of the data
     */
    public PageData(Link link, int status) {
        this.link = link;
        this.status = status;
    }
    
    /**
     * @return Returns the link.
     */
    public Link getLink() {
        return link;
    }

    /**
     * @return Returns the status.
     */
    public int getStatus() {
        return status;
    }
    /**
     * @param status The status to set.
     */
    public void setStatus(int status) {
        this.status = status;
    }
    
    /**
     * @return Returns the data of the page.
     */
    abstract public Object getData();
    
}