/*
 * Copyright 2006 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.parser.httpclient;

import org.apache.commons.httpclient.auth.AuthScope;

/** 
 * This utility class helps users who don't want to know any details of HttpClient.
 * 
 * The class helps to create an authentication scope consisting of a host name,
 * a port number, a realm name and an authentication scheme name which 
 * a credentials apply to. 
 */
public class AuthScopeUtil {
	
    /** 
     * Represents any host.  
     */
    public static final String ANY_HOST = AuthScope.ANY_HOST;

    /** 
     * Represents any port.  
     */
    public static final int ANY_PORT = AuthScope.ANY_PORT;

    /** 
     * Represents any realm.  
     */
    public static final String ANY_REALM = AuthScope.ANY_REALM;

    /** 
     * Represents any authentication scheme.  
     */
    public static final String ANY_SCHEME = AuthScope.ANY_SCHEME;

    /** 
     * Creates a new credentials scope for the given 
     * <tt>host</tt>, <tt>port</tt>, any realm name, and any
     * authentication scheme.
     * 
     * @param host the host the credentials apply to. May be set
     *   to <tt>null</tt> if credenticals are applicable to
     *   any host. 
     * @param port the port the credentials apply to. May be set
     *   to negative value if credenticals are applicable to
     *   any port.
     *    
     * @see org.apache.commons.httpclient.auth.AuthScope#AuthScope(java.lang.String, int)
     */
	public static AuthScope createAuthScope(String host, int port) {
		return new AuthScope(host, port);
	}
	
	/** 
	 * Creates a new credentials scope for the given 
     * <tt>host</tt>, <tt>port</tt>, <tt>realm</tt>, and 
     * <tt>authentication scheme</tt>.
     * 
     * @param host the host the credentials apply to. May be set
     *   to <tt>null</tt> if credenticals are applicable to
     *   any host. 
     * @param port the port the credentials apply to. May be set
     *   to negative value if credenticals are applicable to
     *   any port. 
     * @param realm the realm the credentials apply to. May be set 
     *   to <tt>null</tt> if credenticals are applicable to
     *   any realm. 
     * @param scheme the authentication scheme the credentials apply to. 
     *   May be set to <tt>null</tt> if credenticals are applicable to
     *   any authentication scheme. 
     *   
     * @see org.apache.commons.httpclient.auth.AuthScope#AuthScope(java.lang.String, int, java.lang.String, java.lang.String)
     */
	public static AuthScope createAuthScope(String host, int port, String realm, String scheme) {
		return new AuthScope(host, port, realm, scheme);
	}

}
