/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.util;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.httpclient.URI;
import org.apache.commons.httpclient.URIException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.torunski.crawler.filter.ILinkFilter;

/**
 * Helpful methods for links.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.6 $
 */
public class LinksUtil {
    
    private static transient final Log log = LogFactory.getLog(LinksUtil.class);
    
    /**
     * @param currentLink the current page in which the new link is contained
     * @param newLink the to be completed link
     * @return a full qualified link or <code>null</code> if the newLink can't be parsed. 
     */
    public static final String getURI(String currentLink, String newLink) {
        if (newLink == null) {
            return null;
        }
        
        try {
            // workaround for http:/path/example.htm
            if (!newLink.startsWith("http://") && newLink.startsWith("http:/")) {
                newLink = newLink.substring(5);
            }
            
            // workaround for https:/path/example.htm
            if (!newLink.startsWith("https://") && newLink.startsWith("https:/")) {
                newLink = newLink.substring(5);
            }
            
            // create new URIs
            // TODO check new URI constructors
            URI base = new URI(currentLink, false);
            URI newURI = new URI(base, newLink, false);
            
            // ignore the schemes other than http
            if (!"http".equals(newURI.getScheme()) && !"https".equals(newURI.getScheme())) {
                return null;
            }
            
            return newURI.toString();
        } catch (URIException e) {
            log.info("URI problem with current link '" + currentLink + "' and new link '" + newLink + "'", e);
            return null;
        }
    }
    
    /**
     * @param url the url (origin) of the page
     * @param content the complete web page
     * @return a collection of new links
     */
    public static Collection retrieveLinks(String url, String content, ILinkFilter linkFilter) {
        // FIXME performance and memory!!!
        String pageLower = content.toLowerCase();
        
        Collection result = new ArrayList();
        
        // find all the links
        int pos = 0;
        while (pos < content.length()) {
            // find a link
            // FIXME performance with reg expression
            // TODO image links extraction
        	// TODO <a class="sub" href="../download/meilensteine_bhf_bank.pdf" onclick="return loadPDF(this.href,1);" onkeypress="return loadPDF(this.href);" target="_blank">439KB</a>
            int start = pageLower.indexOf("<a href=\"", pos);
            if (start != -1) {
                int end = content.indexOf("\"", start + 9);

                // create a full qualified link
                String link = LinksUtil.getURI(url, content.substring(start+9, end));

                // if no filter is set or a set filter accepts the link, then add it to the list
                if ((link != null) && ((linkFilter == null) || (linkFilter.accept(url, link)))) {
                    result.add(link);
                } 
                
                // next parsing position
                pos = end + 1;
            } else {
                // end parsing
                pos = content.length();
            }
        }
        
        return result;
    }
   
}
