/*
 * Copyright 2005 by Lars Torunski
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.torunski.crawler.util;

/**
 * A stop watch for milliseconds.
 * 
 * @author Lars Torunski
 * @version $Revision: 1.2 $
 */
public final class StopWatch {
    
    /** the total time in milliseconds */
    private long total = 0;
    
    /** the start time in milliseconds */
    private long start;
    
    /**
     * Starts the stop watch.
     */
    public void start() {
        start = System.currentTimeMillis();
    }
    
    /**
     * Stops the stop watch.
     * @return the millis between the last start and current stop of this watch.
     */
    public long stop() {
    	long diff = System.currentTimeMillis() - start;
        total += diff;
        return diff;
    }
    
    /**
     * Resets the stop watch to 0.
     */
    public void reset() {
        total = 0;
    }
    
    /**
     * @return returns the stopped total time in milliseconds.
     */
    public long getTime() {
        return total;
    }

}
